@@ -146,7 +146,7 @@ def create_venue_uwsgi_file(VENUE_ROOT, VENUE_NAME):
         srcdata = f.read()
     outfile = os.path.join(VENUE_ROOT, 'uwsgi.ini')
     o = open(outfile, 'w')
-    o.write(srcdata.format(VENUE_ROOT=VENUE_ROOT))
+    o.write(srcdata.format(VENUE_ROOT=VENUE_ROOT, VENUE_NAME=VENUE_NAME))
     o.close()
     return
 
